==> kubernetes-model-0.1.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/ObjectMetaFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ObjectMetaFluent<T extends ObjectMetaFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Map<String, String> annotations = new HashMap();     String creationTimestamp;     String deletionTimestamp;     String generateName;     Map<String, String> labels = new HashMap();     String name;     String namespace;     String resourceVersion;     String selfLink;     String uid;     Map<String, Object> additionalProperties = new HashMap();

    public T addToAnnotations( String key,  String value){
    if(key != null && value != null) {this.annotations.put(key, value);} return (T)this;
    }
    public Map<String, String> getAnnotations(){
    return this.annotations;
    }
    public T withAnnotations( Map<String, String> annotations){
    this.annotations.clear();if (annotations != null) {this.annotations.putAll(annotations);} return (T) this;
    }
    public String getCreationTimestamp(){
    return this.creationTimestamp;
    }
    public T withCreationTimestamp( String creationTimestamp){
    this.creationTimestamp=creationTimestamp; return (T) this;
    }
    public String getDeletionTimestamp(){
    return this.deletionTimestamp;
    }
    public T withDeletionTimestamp( String deletionTimestamp){
    this.deletionTimestamp=deletionTimestamp; return (T) this;
    }
    public String getGenerateName(){
    return this.generateName;
    }
    public T withGenerateName( String generateName){
    this.generateName=generateName; return (T) this;
    }
    public T addToLabels( String key,  String value){
    if(key != null && value != null) {this.labels.put(key, value);} return (T)this;
    }
    public Map<String, String> getLabels(){
    return this.labels;
    }
    public T withLabels( Map<String, String> labels){
    this.labels.clear();if (labels != null) {this.labels.putAll(labels);} return (T) this;
    }
    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public String getNamespace(){
    return this.namespace;
    }
    public T withNamespace( String namespace){
    this.namespace=namespace; return (T) this;
    }
    public String getResourceVersion(){
    return this.resourceVersion;
    }
    public T withResourceVersion( String resourceVersion){
    this.resourceVersion=resourceVersion; return (T) this;
    }
    public String getSelfLink(){
    return this.selfLink;
    }
    public T withSelfLink( String selfLink){
    this.selfLink=selfLink; return (T) this;
    }
    public String getUid(){
    return this.uid;
    }
    public T withUid( String uid){
    this.uid=uid; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }



}

==> kubernetes-model-1.0.6-sources.jar: annotations/io/fabric8/kubernetes/api/model/ObjectMetaFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ObjectMetaFluent<T extends ObjectMetaFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Map<String, String> annotations = new HashMap();     String creationTimestamp;     String deletionTimestamp;     String generateName;     Long generation;     Map<String, String> labels = new HashMap();     String name;     String namespace;     String resourceVersion;     String selfLink;     String uid;     Map<String, Object> additionalProperties = new HashMap();

    public T addToAnnotations( String key,  String value){
    if(key != null && value != null) {this.annotations.put(key, value);} return (T)this;
    }
    public Map<String, String> getAnnotations(){
    return this.annotations;
    }
    public T withAnnotations( Map<String, String> annotations){
    this.annotations.clear();if (annotations != null) {this.annotations.putAll(annotations);} return (T) this;
    }
    public String getCreationTimestamp(){
    return this.creationTimestamp;
    }
    public T withCreationTimestamp( String creationTimestamp){
    this.creationTimestamp=creationTimestamp; return (T) this;
    }
    public String getDeletionTimestamp(){
    return this.deletionTimestamp;
    }
    public T withDeletionTimestamp( String deletionTimestamp){
    this.deletionTimestamp=deletionTimestamp; return (T) this;
    }
    public String getGenerateName(){
    return this.generateName;
    }
    public T withGenerateName( String generateName){
    this.generateName=generateName; return (T) this;
    }
    public Long getGeneration(){
    return this.generation;
    }
    public T withGeneration( Long generation){
    this.generation=generation; return (T) this;
    }
    public T addToLabels( String key,  String value){
    if(key != null && value != null) {this.labels.put(key, value);} return (T)this;
    }
    public Map<String, String> getLabels(){
    return this.labels;
    }
    public T withLabels( Map<String, String> labels){
    this.labels.clear();if (labels != null) {this.labels.putAll(labels);} return (T) this;
    }
    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public String getNamespace(){
    return this.namespace;
    }
    public T withNamespace( String namespace){
    this.namespace=namespace; return (T) this;
    }
    public String getResourceVersion(){
    return this.resourceVersion;
    }
    public T withResourceVersion( String resourceVersion){
    this.resourceVersion=resourceVersion; return (T) this;
    }
    public String getSelfLink(){
    return this.selfLink;
    }
    public T withSelfLink( String selfLink){
    this.selfLink=selfLink; return (T) this;
    }
    public String getUid(){
    return this.uid;
    }
    public T withUid( String uid){
    this.uid=uid; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }



}
